# Core Developers

----------
- Sepand Haghighi - Open Science Laboratory ([Github](https://github.com/sepandhaghighi))
- Sadra Sabouri - Open Science Laboratory ([Github](https://github.com/sadrasabouri))

# Other Contributors
----------
- [@zhmbshr](https://github.com/zhmbshr) **
- [@ivanovmg](https://github.com/ivanovmg)
- [@ahmadsalimi](https://github.com/ahmadsalimi)

** Graphic designer